# File generated from our OpenAPI spec
from __future__ import absolute_import, division, print_function

from stripe.stripe_object import StripeObject


class UsageRecordSummary(StripeObject):
    OBJECT_NAME = "usage_record_summary"
